@@ -27,13 +27,13 @@ import requests
 import six
 
 from google.cloud import exceptions
+from google.cloud import iam_credentials_v1
 from google.cloud import storage
 from google.cloud.storage._helpers import _base64_md5hash
 from google.cloud.storage.bucket import LifecycleRuleDelete
 from google.cloud.storage.bucket import LifecycleRuleSetStorageClass
 from google.cloud import kms
 import google.oauth2
-
 from test_utils.retry import RetryErrors
 from test_utils.system import unique_resource_id
 from test_utils.vpcsc_config import vpcsc_config
@@ -109,7 +109,6 @@ class TestClient(unittest.TestCase):
 
     def test_get_service_account_email(self):
         domain = "gs-project-accounts.iam.gserviceaccount.com"
-
         email = Config.CLIENT.get_service_account_email()
 
         new_style = re.compile(r"service-(?P<projnum>[^@]+)@" + domain)
@@ -174,7 +173,23 @@ class TestStorageBuckets(unittest.TestCase):
         self.case_buckets_to_delete.append(new_bucket_name)
         self.assertEqual(created.name, new_bucket_name)
 
+    def test_bucket_create_w_alt_storage_class(self):
+        from google.cloud.storage import constants
+
+        new_bucket_name = "bucket-w-archive" + unique_resource_id("-")
+        self.assertRaises(
+            exceptions.NotFound, Config.CLIENT.get_bucket, new_bucket_name
+        )
+        bucket = Config.CLIENT.bucket(new_bucket_name)
+        bucket.storage_class = constants.ARCHIVE_STORAGE_CLASS
+        retry_429_503(bucket.create)()
+        self.case_buckets_to_delete.append(new_bucket_name)
+        created = Config.CLIENT.get_bucket(new_bucket_name)
+        self.assertEqual(created.storage_class, constants.ARCHIVE_STORAGE_CLASS)
+
     def test_lifecycle_rules(self):
+        from google.cloud.storage import constants
+
         new_bucket_name = "w-lifcycle-rules" + unique_resource_id("-")
         self.assertRaises(
             exceptions.NotFound, Config.CLIENT.get_bucket, new_bucket_name
@@ -182,13 +197,17 @@ class TestStorageBuckets(unittest.TestCase):
         bucket = Config.CLIENT.bucket(new_bucket_name)
         bucket.add_lifecycle_delete_rule(age=42)
         bucket.add_lifecycle_set_storage_class_rule(
-            "COLDLINE", is_live=False, matches_storage_class=["NEARLINE"]
+            constants.COLDLINE_STORAGE_CLASS,
+            is_live=False,
+            matches_storage_class=[constants.NEARLINE_STORAGE_CLASS],
         )
 
         expected_rules = [
             LifecycleRuleDelete(age=42),
             LifecycleRuleSetStorageClass(
-                "COLDLINE", is_live=False, matches_storage_class=["NEARLINE"]
+                constants.COLDLINE_STORAGE_CLASS,
+                is_live=False,
+                matches_storage_class=[constants.NEARLINE_STORAGE_CLASS],
             ),
         ]
 
@@ -242,6 +261,57 @@ class TestStorageBuckets(unittest.TestCase):
         bucket.update()
         self.assertEqual(bucket.labels, {})
 
+    def test_get_set_iam_policy(self):
+        import pytest
+        from google.cloud.storage.iam import STORAGE_OBJECT_VIEWER_ROLE
+        from google.api_core.exceptions import BadRequest, PreconditionFailed
+
+        bucket_name = "iam-policy" + unique_resource_id("-")
+        bucket = retry_429_503(Config.CLIENT.create_bucket)(bucket_name)
+        self.case_buckets_to_delete.append(bucket_name)
+        self.assertTrue(bucket.exists())
+
+        policy_no_version = bucket.get_iam_policy()
+        self.assertEqual(policy_no_version.version, 1)
+
+        policy = bucket.get_iam_policy(requested_policy_version=3)
+        self.assertEqual(policy, policy_no_version)
+
+        member = "serviceAccount:{}".format(Config.CLIENT.get_service_account_email())
+
+        BINDING_W_CONDITION = {
+            "role": STORAGE_OBJECT_VIEWER_ROLE,
+            "members": {member},
+            "condition": {
+                "title": "always-true",
+                "description": "test condition always-true",
+                "expression": "true",
+            },
+        }
+        policy.bindings.append(BINDING_W_CONDITION)
+
+        with pytest.raises(
+            PreconditionFailed, match="enable uniform bucket-level access"
+        ):
+            bucket.set_iam_policy(policy)
+
+        bucket.iam_configuration.uniform_bucket_level_access_enabled = True
+        bucket.patch()
+
+        policy = bucket.get_iam_policy(requested_policy_version=3)
+        policy.bindings.append(BINDING_W_CONDITION)
+
+        with pytest.raises(BadRequest, match="at least 3"):
+            bucket.set_iam_policy(policy)
+
+        policy.version = 3
+        returned_policy = bucket.set_iam_policy(policy)
+        self.assertEqual(returned_policy.version, 3)
+        self.assertEqual(returned_policy.bindings, policy.bindings)
+
+        fetched_policy = bucket.get_iam_policy(requested_policy_version=3)
+        self.assertEqual(fetched_policy.bindings, returned_policy.bindings)
+
     @unittest.skipUnless(USER_PROJECT, "USER_PROJECT not set in environment.")
     def test_crud_bucket_with_requester_pays(self):
         new_bucket_name = "w-requester-pays" + unique_resource_id("-")
@@ -882,6 +952,8 @@ class TestStorageSignURLs(unittest.TestCase):
         payload=None,
         expiration=None,
         encryption_key=None,
+        service_account_email=None,
+        access_token=None,
     ):
         expiration = self._morph_expiration(version, expiration)
 
@@ -892,7 +964,12 @@ class TestStorageSignURLs(unittest.TestCase):
             blob = self.blob
 
         signed_url = blob.generate_signed_url(
-            expiration=expiration, method=method, client=Config.CLIENT, version=version
+            expiration=expiration,
+            method=method,
+            client=Config.CLIENT,
+            version=version,
+            service_account_email=service_account_email,
+            access_token=access_token,
         )
 
         headers = {}
@@ -965,6 +1042,35 @@ class TestStorageSignURLs(unittest.TestCase):
             version="v4",
         )
 
+    def test_create_signed_read_url_v2_w_access_token(self):
+        client = iam_credentials_v1.IAMCredentialsClient()
+        service_account_email = Config.CLIENT._credentials.service_account_email
+        name = client.service_account_path("-", service_account_email)
+        scope = [
+            "https://www.googleapis.com/auth/devstorage.read_write",
+            "https://www.googleapis.com/auth/iam",
+        ]
+        response = client.generate_access_token(name, scope)
+        self._create_signed_read_url_helper(
+            service_account_email=service_account_email,
+            access_token=response.access_token,
+        )
+
+    def test_create_signed_read_url_v4_w_access_token(self):
+        client = iam_credentials_v1.IAMCredentialsClient()
+        service_account_email = Config.CLIENT._credentials.service_account_email
+        name = client.service_account_path("-", service_account_email)
+        scope = [
+            "https://www.googleapis.com/auth/devstorage.read_write",
+            "https://www.googleapis.com/auth/iam",
+        ]
+        response = client.generate_access_token(name, scope)
+        self._create_signed_read_url_helper(
+            version="v4",
+            service_account_email=service_account_email,
+            access_token=response.access_token,
+        )
+
     def _create_signed_delete_url_helper(self, version="v2", expiration=None):
         expiration = self._morph_expiration(version, expiration)
 
@@ -1235,34 +1341,38 @@ class TestStorageRewrite(TestStorageFiles):
 
 class TestStorageUpdateStorageClass(TestStorageFiles):
     def test_update_storage_class_small_file(self):
+        from google.cloud.storage import constants
+
         blob = self.bucket.blob("SmallFile")
 
         file_data = self.FILES["simple"]
         blob.upload_from_filename(file_data["path"])
         self.case_blobs_to_delete.append(blob)
 
-        blob.update_storage_class("NEARLINE")
+        blob.update_storage_class(constants.NEARLINE_STORAGE_CLASS)
         blob.reload()
-        self.assertEqual(blob.storage_class, "NEARLINE")
+        self.assertEqual(blob.storage_class, constants.NEARLINE_STORAGE_CLASS)
 
-        blob.update_storage_class("COLDLINE")
+        blob.update_storage_class(constants.COLDLINE_STORAGE_CLASS)
         blob.reload()
-        self.assertEqual(blob.storage_class, "COLDLINE")
+        self.assertEqual(blob.storage_class, constants.COLDLINE_STORAGE_CLASS)
 
     def test_update_storage_class_large_file(self):
+        from google.cloud.storage import constants
+
         blob = self.bucket.blob("BigFile")
 
         file_data = self.FILES["big"]
         blob.upload_from_filename(file_data["path"])
         self.case_blobs_to_delete.append(blob)
 
-        blob.update_storage_class("NEARLINE")
+        blob.update_storage_class(constants.NEARLINE_STORAGE_CLASS)
         blob.reload()
-        self.assertEqual(blob.storage_class, "NEARLINE")
+        self.assertEqual(blob.storage_class, constants.NEARLINE_STORAGE_CLASS)
 
-        blob.update_storage_class("COLDLINE")
+        blob.update_storage_class(constants.COLDLINE_STORAGE_CLASS)
         blob.reload()
-        self.assertEqual(blob.storage_class, "COLDLINE")
+        self.assertEqual(blob.storage_class, constants.COLDLINE_STORAGE_CLASS)
 
 
 class TestStorageNotificationCRUD(unittest.TestCase):
